---
icon: lucide/heart-handshake
---

<!-- SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# Contributing

To efficiently address our users' needs, we carefully designed our contributing
guidelines and optimized our issue templates to ensure a great overall experience
with our project.

Our goal is to ensure that our documentation, as well as our issue tracker, are
__well-structured__, __easy to navigate__, and __searchable__, so you can find
what you need quickly and efficiently. Thus, when you follow our contribution
guidelines, we can help you much faster.

In this section, we guide you through our processes.

## Create an Issue

<div class="grid cards" markdown>

- :lucide-bug: &nbsp;
    __Something is not working?__

    ---

    Report a bug in Zenzic by creating an issue containing a reproduction.

    ---

    :lucide-arrow-right: [Report a bug][report a bug]

- :material-file-edit-outline: &nbsp;
    __Missing information in our docs?__

    ---

    Report missing information or potential inconsistencies in our
    documentation.

    ---

    :lucide-arrow-right: [Report a docs issue][report a docs issue]

- :material-lightbulb-on-outline: &nbsp;
    __Want to submit an idea?__

    ---

    Propose a change, feature request, or suggest an improvement.

    ---

    :lucide-arrow-right: [Request a change][request a change]

</div>

## Contribute

<div class="grid cards" markdown>

- :lucide-git-pull-request: &nbsp;
    __Want to contribute to the code?__

    ---

    Contribute to the development of Zenzic by making a pull request.

    ---

    :lucide-arrow-right: [Make a pull request][make a pull request]

</div>

  [report a bug]: report-a-bug.md
  [report a docs issue]: report-a-docs-issue.md
  [request a change]: request-a-change.md
  [make a pull request]: pull-requests.md

## Checklist

Before interacting within the project, please take a moment to consider the
following questions. By doing so, you ensure that you use the correct issue
template and provide all necessary information when interacting with our
community.

!!! warning "Issues and comments are forever"

    Please note that everything you write is permanent and will remain for
    everyone to read – forever. Therefore, we kindly ask you to always be
    nice and constructive, complying with our [Code of Conduct].

### Before creating an issue

- Are you using the appropriate issue template, or is there another one that
  better fits the context of your request?

- Have you checked if a similar bug report or change request has already been
  created, or have you stumbled upon something that might be related?

- Did you fill out every field as requested, and did you provide all additional
  information we maintainers need to comprehend your request?

### Before commenting

- Is your comment relevant to the topic of the current issue, or is it a better
  idea to create a new issue, as it's not or only loosely related?

- Does your comment add value to the conversation? Is it constructive and
  respectful to our community and us maintainers? Could you just use a
  [reaction] instead?

## Incomplete contributions

We have carefully designed our contribution process to ensure that issues on our
[issue tracker] can be reviewed and addressed efficiently. Each field in our
issue templates is thoughtfully structured to capture the essential details
needed to fully understand your concern.

Therefore, we require all requested information to be provided in full.

The checklist at the end of each template is a tool to help you verify that
you've included everything necessary – it should not be marked off unless each
point has been fully addressed.

__We reserve the right to handle issues that do not adhere to our guidelines
as follows:__

### Incomplete issues

We _reserve the right to close issues lacking essential information_, such as
missing reproductions or those not adhering to the quality standards and
requirements specified in our issue templates. We'll reopen an issue once the
missing information has been provided.

### Questions as issues

We _reserve the right to close questions opened as any kind of issue_. The
issue tracker is not a place for questions, but rather for detailed
[bug reports], [documentation issues], and [change requests] that adhere to the
quality standards laid out in this guide.

### Duplicated issues

To maintain organized and efficient communication within our [issue tracker],
we _reserve the right to close any duplicated issues_.

### Reopened issues

We further _reserve the right to immediately close issues that are reopened
without providing new information_.

  [reaction]: https://github.blog/2016-03-10-add-reactions-to-pull-requests-issues-and-comments/
  [issue tracker]: https://github.com/PythonWoods/zenzic/issues
  [bug reports]: report-a-bug.md
  [documentation issues]: report-a-docs-issue.md
  [change requests]: request-a-change.md
